#!/bin/ksh
#######################################################################################
#
# IBM Enterprise Information Portal for Multiplatforms V7.1  (program number 5697-G29)
# (c ) Copyright IBM Corp. 1998, 2000. All Rights Reserved.
# IBM Content Manager for Multiplatforms V6.1  (program number 5648-D03)
# (c ) Copyright IBM Corp. 1994, 2000. All Rights Reserved.
#
# Licensed Materials - Property of IBM
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corporation
#
###################################################################################
#***********************************************************************
# Program name  : in/cmxupdate.sh                                      *
#                                                                      *
#                                                                      *
# Description   : Apply the PTF Fixes                                  *
# Change History:                                                      *
#  072001 f26582 pari update for 7120 (any level in the media, generic)*
#  071201 f26422 pari update for 7120 (7130 already exists, exit)      *
#  070301 f25541 pari update for 7120 (dpb)                            *
#  070301 f25541 gchang update for 7120                                *
#  021601 d24704 gchang update for 7120                                *
#  110399 f17344 ckc  Initial                                          *
#***********************************************************************
#
# Get the current directory where the installation images are
#
#set -x
clear
if [[ $1 != "" ]] then
   FrnxImgDir=$1
else
   FrnxImgDir=`pwd`
fi


#
# Make sure "root" is the user ID
#

user=`whoami`
if [[ $user != "root" ]]; then
   echo "\nThe AIX 'root' user ID is required."
   echo "The current user ID, $user, can not perform the AIX installation function.\n"
   exit 1
fi # end of if current user is not root

if [[ -a /tmp/cmbxinst$$.log ]] then
    /usr/bin/rm /tmp/cmbxinst$$.log
fi

#
# Messages                                                              
#

msg1="No fileset(s) will be updated."
msg2="\nAbove EIP fileset(s) exist on your machine.\nThey will be updated if fix are available on installation media.\nPress Enter to update. Press other key to quit.\n"
msg3="\n\nThe codes on your system have been updated."
msg4="has been updated successfully."
msg5="\nError occurred while updating "
msg6="Check "/tmp/cmbxinst$$.log" for detail information."
msg7="\nThere is no CM 6.1 server installed on your machine.\nWe suggest you to move your CM toolkit component to 7.1 version.\nPress Enter if you agree. Press other key if you don't.\n"


#
# check component exists on local system
# display only the selectable ones
#

function checkcomp
{
 for ptffile in `ls *.ptfimg`; do
     filesetname=`echo $ptffile | sed -e "s/.ptfimg//"`
     lslpp -l $filesetname > /dev/null 2>&1
     if [[ $? -eq 0 ]] then
        descrip1=`lslpp -l $filesetname | grep frn`
        descrip2=`lslpp -l $filesetname | grep cmb`
        descrip3=`lslpp -l $filesetname | grep COMMITTED`
        echo $descrip3 | grep frn > /dev/null 2>&1
        if [[ $? -eq 0 ]]; then
              echo $descrip3
        else
           if [[ "$descrip1" = "" ]]; then
	      echo $descrip2
	   else
	      echo $descrip1' '$descrip3
           fi
        fi
        comp="$comp $filesetname " 
     fi
 done
}

#
# invoke installp to update files, will bring in the prereq if needed
#

function update
{
  #check if fix exists on installation media
  installp -L -d $CurrImgDir | grep $xfs > /dev/null
  if [[ $? -eq 0 ]] 
  then 
      echo "Updating " $xfs
      installp -ac  -X -V2 -d $CurrImgDir $xfs >> /tmp/cmbxinst$$.log 2>&1
      if [[ $? -eq 0 ]] then
          echo $xfs $msg4
      else
          echo $msg5$xfs"."
          echo $msg6
      fi
  fi
}
CMBXOUT=/tmp/cmbxinst$$
function checkstatus
{
     if [[ $? -eq 0 ]] then
          echo $xfs $msg4
      else
          echo $msg5$xfs"."
          echo $msg6
      fi

}

function frncommoninstall
{
     installp -ac -d $CurrImgDir -X "frn.ServerUtilities.rte" >>$CMBXOUT.log 2>&1
     xfs="frn.ServerUtilities.rte"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ServerUtilities.conv" >>$CMBXOUT.log 2>&1
     xfs="frn.ServerUtilities.conv"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ServerUtilities.Readme.loc.$LANG" >>$CMBXOUT.log 2>&1
     xfs="frn.ServerUtilities.Readme.loc.$LANG"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ServerUtilities.msg.$LANG" >>$CMBXOUT.log 2>&1
     xfs="frn.ServerUtilities.msg.$LANG"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ServerUtilities.cfg.loc.$LANG" >>$CMBXOUT.log 2>&1
     xfs="frn.ServerUtilities.cfg.loc.$LANG"
     checkstatus
}

function frntoolkitinstall
{
     installp -ac -d $CurrImgDir -X "frn.ToolkitCAPI.rte" >>$CMBXOUT.log 2>&1
     xfs="frn.ToolkitCAPI.rte"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ToolkitCAPI.Samples" >>$CMBXOUT.log 2>&1
     xfs="frn.ToolkitCAPI.Samples"
     checkstatus
     installp -ac -d $CurrImgDir -X "frn.ToolkitCAPI.cfg.loc.$LANG" >>$CMBXOUT.log 2>&1
     xfs="frn.ToolkitCAPI.cfg.loc.$LANG"
     checkstatus
}
#
############################ Begin CSD3 #########
cd $FrnxImgDir
CurrImgDir=$FrnxImgDir
#if [[ $comp = "cmb.DynamicPageBuilder.base" ]] then
     lslpp -l cmb.DynamicPageBuilder.base >/dev/null 2>&1
     RC10=$?
     lslpp -l cmb.DLVI.Csamples.base >/dev/null 2>&1
     RC11=$?
     lslpp -l cmb.DLVI.Jsamples.base >/dev/null 2>&1
     RC12=$?
     lslpp -l cmb.WaterMarking.base >/dev/null 2>&1
     RC13=$?
     lslpp -l cmb.WaterMarking.Samples >/dev/null 2>&1
     RC14=$?
  if [[ $RC10 != 0 ]] then
     if [[ $RC11 = 0 || $RC12 = 0 || $RC13 = 0 || $RC14 = 0 ]] then
       echo "Installing the component Dynamic Page Builder...."
       installp -ac -d $CurrImgDir/DPB -X cmb.DynamicPageBuilder.base >> /tmp/cmbxinst$$.log 2>&1
       RC15=$?
       installp -ac -d $CurrImgDir/DPB -X cmb.DynamicPageBuilder.Samples >> /tmp/cmbxinst$$.log 2>&1
       RC16=$?
       installp -ac -d $CurrImgDir/DPB -X cmb.DynamicPageBuilder.Samples.loc.$LANG >> /tmp/cmbxinst$$.log 2>&1
       RC17=$?

        if [[ $RC15 -ne 0 ]] then
        echo "Warning... cmb.DynamicPageBuilder.base fileset is not installed."
        fi
        if [[ $RC16 -ne 0 ]] then
         echo "Warning... cmb.DynamicPageBuilder.Samples fileset is not installed ...."
        fi
        if [[ $RC17 -ne 0 ]] then
          echo "Warning... cmb.DynamicPageBuilder.Samples.loc.$LANG fileset is not installed ...."
        fi
     fi
  fi
#fi
########################### End CSD3 #########


#
# go through components and check if on the local system,
# if exists on the local system, store them in comp
#

comp=""
#cd $FrnxImgDir
checkcomp

#
# if no component exists on the local system, exit
#

if [[ -z $comp ]] then
   echo $msg1
   exit
#
# if component exists on the local system, ready to update
# give the last opportunity for user to cancel/exit without installation        
#
else
# current system's EIP level....
     y=`/usr/bin/lslpp -qcl cmb.UnInstallation.base | cut -d":" -f3`
# EIP level of the ship media...
     clvl=`/usr/sbin/installp -L -d $CurrImgDir |grep cmb.UnInstallation.base`
     x=`echo $clvl | cut -d":" -f3`
     eval $(echo $x | awk -F. '{printf "xVer=%d; xRelease=%d; xMod=%d; xFix=%d", $1, $2, $3, $4}')

# Derive current system's ver/rel/mod/fix numbers
     eval $(echo $y | awk -F. '{printf "yVer=%d; yRelease=%d; yMod=%d; yFix=%d", $1, $2, $3, $4}')

	if (( $xVer == $yVer && $xRelease == $yRelease && $xMod == $yMod && $xFix == $yFix )) then
  	    echo "\nYou have EIP $x (update) already installed in your system"
  	    echo "\nForce install of same level of updates are not allowed"
  	    echo "\nExiting....."
  	    exit 1
	else 
   	     echo $msg2
   	     read x
   	       if [[ -n $x ]] then
   	         exit
   	       fi
   	 fi
fi

#
# update the components when fileset(s) was installed and Fixes available
#
# CurrImgDir=$FrnxImgDir
for xfs in $comp
do
    update $xfs
done

#
# Check to see if any CM fileset available;
# Also make sure EIP not in 7.1.0.0 level before updates CM 
#
y=`lslpp -l cmb.DevelopmentToolkit.base | grep 7.1.0.235 `

if [[ -d $FrnxImgDir/CM71 && -z $y ]] then
    RC1=`lslpp -l frn.LibraryServer.base | grep 6.1.* `
    RC2=`lslpp -l frn.ObjectServer.base | grep 6.1.* `
# Update Toolkit if no CM 6.1 server exists
    if [[ -z $RC1 && -z $RC2 ]] then
#
# if component exists on the local system, ready to update
# give the last opportunity for user to cancel/exit without installation        
#
        echo $msg7
        read x
        if [[ -n $x ]] then
            exit
        fi
        
        CurrImgDir=$FrnxImgDir/CM71
        frncommoninstall
        frntoolkitinstall
     fi
fi
#
# display post update message
#
echo $msg3

return 0
